<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="98"/>
        <source>Enter the number to configure: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="103"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="100"/>
        <source>Package Installer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="109"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="288"/>
        <source>The deb package may be broken</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="296"/>
        <source>You can only install local deb packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="305"/>
        <source>Already Added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="314"/>
        <source>%1 does not exist, please reselect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="425"/>
        <source>Bulk Install</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="135"/>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="101"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="118"/>
        <source>Installation failed, please check your network connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="103"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="106"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="110"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="122"/>
        <source>Installation failed, insufficient disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>No digital signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="131"/>
        <source>Invalid digital signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="138"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="577"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1386"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="143"/>
        <source>Installation Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="575"/>
        <source>Unmatched package architecture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="581"/>
        <source>Failed to install %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="582"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="587"/>
        <source>Broken dependencies: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="852"/>
        <source>Unable to install - no digital signature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="853"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="856"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="857"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="926"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="928"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="929"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1385"/>
        <source>Unable to install</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="896"/>
        <source>This package does not have a valid digital signature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="60"/>
        <source>Drag deb packages here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="102"/>
        <source>Select File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="46"/>
        <source>Show details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="46"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="184"/>
        <source>Install</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="185"/>
        <source>Done</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="187"/>
        <source>Back</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="477"/>
        <source>Dependencies in the repository</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="483"/>
        <source>Missing dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="532"/>
        <source>Installing dependencies: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
        <source>Installing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="78"/>
        <source>Installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="82"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="86"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="247"/>
        <source>Same version installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
        <source>Later version installed: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="253"/>
        <source>Earlier version installed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="158"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="43"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="57"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="58"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="21"/>
        <source>Basic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="22"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="356"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="822"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="986"/>
        <source>Reinstall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="348"/>
        <source>Install</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="352"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="360"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="364"/>
        <source>Back</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="368"/>
        <source>Done</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="702"/>
        <source>Installed successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="707"/>
        <source>Uninstalled successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="717"/>
        <source>Uninstall Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="726"/>
        <source>Collapse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="746"/>
        <source>Dependencies in the repository</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="752"/>
        <source>Missing dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="821"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="985"/>
        <source>Same version installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="825"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="989"/>
        <source>Later version installed: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="827"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
        <source>Downgrade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="830"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="994"/>
        <source>Earlier version installed: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="832"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="996"/>
        <source>Update</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="895"/>
        <source>Installing dependencies: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1031"/>
        <source>Failed to install %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="57"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="548"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="573"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="701"/>
        <source>Show details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="43"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="58"/>
        <source>Show dependencies</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="598"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="706"/>
        <source>Show details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="29"/>
        <source>Show related packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="29"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="50"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="52"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="126"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="128"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="61"/>
        <location filename="../src/deb-installer/main.cpp" line="62"/>
        <source>Package Installer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="63"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
